Args

Struct Args 

pub struct Args {
Show 14 fields pub file_a: Option<PathBuf>, pub file_b: Option<PathBuf>, pub format_a: Option<InputFormat>, pub format_b: Option<InputFormat>, pub output: Option<PathBuf>, pub output_format: OutputFormat, pub graph_a: Option<String>, pub graph_b: Option<String>, pub quiet: bool, pub ci: bool, pub view: bool, pub no_open: bool, pub bind: String, pub ignore_blank_nodes: bool,
}
Compare two RDF files and emit the diff as a quad dataset with two named graphs.

Fields

file_a: Option<PathBuf>

First (left) RDF file.

file_b: Option<PathBuf>

Second (right) RDF file.

format_a: Option<InputFormat>

Override input format for file A (auto-detected from extension by default).

format_b: Option<InputFormat>

Override input format for file B (auto-detected from extension by default).

output: Option<PathBuf>

Output file (defaults to stdout).

output_format: OutputFormat

Output serialization.

graph_a: Option<String>

Override the named-graph IRI for triples only in file A.

graph_b: Option<String>

Override the named-graph IRI for triples only in file B.

quiet: bool

Suppress the summary line on stderr.

ci: bool

Exit with code 1 if any differences are found (useful in CI).

view: bool

Open the diff in the local web viewer after computing it.

no_open: bool

Do not auto-open the system browser when starting the viewer.

bind: String

Bind address for the web viewer.

ignore_blank_nodes: bool

Skip blank-node-bearing triples instead of canonicalising them. By default, when blank nodes are present, the W3C RDFC-1.0 algorithm is used to assign stable labels before diffing.